latest package
==============

.. automodule:: latest
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

latest\.config module
---------------------

.. automodule:: latest.config
    :members:
    :undoc-members:
    :show-inheritance:

latest\.core module
-------------------

.. automodule:: latest.core
    :members:
    :undoc-members:
    :show-inheritance:

latest\.exceptions module
-------------------------

.. automodule:: latest.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

latest\.shortcuts module
------------------------

.. automodule:: latest.shortcuts
    :members:
    :undoc-members:
    :show-inheritance:

latest\.util module
-------------------

.. automodule:: latest.util
    :members:
    :undoc-members:
    :show-inheritance:


